# Smart Chunker Engine: Сводное ТЗ (v0.9)

**Официальный репозиторий:** [git@github.com:maverikod/vvz-smart-chunker-engine.git](git@github.com:maverikod/vvz-smart-chunker-engine.git)

| Раздел              | Ключевые пункты                                                                                                                                       |
| ------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------- |
| **1. Цель и KPI**   | F1 ≥ 0.90, Noise ≤ 3 %, CV\_len ≤ 30 %                                                                                                                |
| **2. Архитектура**  | Pre‑norm → POS‑window → TF‑IDF+Triples (stats\_gate) → Metablocks → MERGE/SPLIT (iterative\_refine) → Metadata → CI reports                           |
| **3. Алгоритмы**    | *Boundary detect* (SBERT Δ 0.15); *Triples* 〈N A V〉 → HDBSCAN → word\_weight; *Score* = Σ(cohesion – λ·boundary); greedy MERGE/SPLIT until ΔScore < ε |
| **4. Форматы**      | raw `.txt`, `config.yaml`, `SemanticChunk` JSON, JUnit‑XML tests                                                                                      |
| **5. Тест‑корпуса** | ML‑RU‑50k, Tech‑EN‑30k, OCR‑RU‑20k, ASR‑RU‑15k, Code‑Mix‑10k                                                                                          |
| **6. CI‑pipeline**  | GitHub Actions ⇒ junit badge; smoke‑test (2 КБ) pre‑commit                                                                                            |

## Основной поток

```
raw_text ──▶ pre_normalize ──▶ pos_window+SBERT
            │
            ├─ stats_gate?──no──▶ hybrid_chunks
            │          │yes
            ▼          ▼
         TF‑IDF   triple_weights
            │          │
            └──▶ topic_core
                       ▼
            metablock_segmenter
                       ▼
                 iterative_refine (MERGE/SPLIT)
                       ▼
                 build_SemanticChunk
                       ▼
               Flat → storage / vector DB
```

## Пороговые значения (дефолт)

```
θ_high  = 0.75
θ_low   = 0.35
λ       = 0.4
cov_min = 0.60
ΔScore ε= 0.01/pass
```

## Модули к разработке

1. **boundary\_segmenter.py** – POS‑окно, SBERT.
2. **stats\_gate.py** – var/entropy/gini.
3. **triple\_extractor.py** – spaCy `ru_core_news_md`.
4. **triple\_cluster.py** – HDBSCAN + weights.
5. **iterative\_refine.py** – greedy MERGE/SPLIT.
6. **metadata\_builder.py** – (из package).
7. **evaluate\_boundaries.py** – F1 + noise.

⚑ *Детализация каждого модуля будет описана по шагам в следующих холстах.*
