# Smart Chunker Engine: ТЗ (часть 2 из N)

**Официальный репозиторий:** [git@github.com:maverikod/vvz-smart-chunker-engine.git](git@github.com:maverikod/vvz-smart-chunker-engine.git)

> **Внимание!** Все операции с метаданными чанков (создание, хранение, экспорт, сериализация, статусы, метрики) должны выполняться исключительно через API и модели пакета [chunk_metadata_adapter](https://pypi.org/project/chunk-metadata-adapter/) (версии >=1.3.0). Форматы, сериализация, экспорт и валидация должны соответствовать [docs/implementation_plan.md](implementation_plan.md) и [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md).

## 2. Архитектура потоков

```
            ┌─ raw_text (.txt / OCR / ASR) ┐
            │                              │
            ▼                              ▼
┌──────────────────────┐       stats_gate?──yes─────▶ TF‑IDF + triple_weights
│ Pre‑Normalize        │
│  • NFC, Unicode fix  │               │no          │
└────────┬─────────────┘               ▼            ▼
         ▼                   ┌───────────────┐  merge/split refine ⟶ optimized_chunks
  POS filter (N V A)         │ window_seg    │
         ▼                   │  window=20    │
 window embed (SBERT)        │  step=10      │
         ▼                   └───────────────┘
  Δcos > thr  ──▶ boundary_detection
         ▼
  initial_chunks ──▶ metablock_split (object|prop|action)
         ▼
  sentence_refine (inside metablock)
         ▼
  triple_extractor  ⟶  triple_cluster (HDBSCAN)
         ▼
  TopicCore build   ⟶  coverage score
         ▼
  iterative_refine (MERGE / SPLIT)  ↺
         ▼
  build_semantic_chunk + lifecycle  RAW…RELIABLE
         ▼
  output: semantic_chunks.json / flat.tsv
```

* Голубые блоки – обяз.
* Зелёные – условно‑включаемые (`stats_gate`).
* Красные стрелки – итеративный цикл до стабилизации `Score`.

## 2.1 Модули и их границы

| Модуль                        | Файл                                       | Вход             | Выход            |
| ----------------------------- | ------------------------------------------ | ---------------- | ---------------- |
| **pre\_normalize**            | `pre_norm.py`                              | raw str          | clean str        |
| **pos\_filter**               | `token_pos.py`                             | str              | list\[str]       |
| **window\_seg**               | `window_segment.py`                        | tokens           | cuts\:list       |
| **boundary\_detection**       | `boundary.py`                              | cuts + thr       | chunks (idx)     |
| **metablock\_split**          | `metablock.py`                             | chunks           | metablocks       |
| **sentence\_refine**          | `sentence_refine.py`                       | metablock        | s‑chunks         |
| **stats\_gate**               | `stats_gate.py`                            | s‑chunks         | bool use\_stats  |
| **triple\_extract & cluster** | `triple_extractor.py`, `triple_cluster.py` | s‑chunks         | weights dict     |
| **iterative\_refine**         | `iterative_refine.py`                      | s‑chunks+weights | opt\_chunks      |
| **metadata & lifecycle**      | `metadata_builder.py`                      | opt\_chunks      | SemanticChunk\[] |

## 2.2 Основные параметры конфигурации (config.yaml)

```yaml
window_size: 20
step_size: 10
thr_cosine: 0.15
var_thr: 0.15
ent_thr: 8.0
gini_thr: 0.25
triple_cluster:
  min_cluster: 5
merge_boundary_high: 0.75
split_cohesion_low: 0.35
lambda_penalty: 0.4
coverage_min: 0.6
max_iter_refine: 4
resources:
  peak_ram_limit_mb: 1024
```

## 2.3 API точки запуска

```bash
chunker run \
  --input  data/raw_text_ml.txt \
  --config config.yaml \
  --algo   hybrid  \  # либо fixed|semantic
  --use_stats auto  \
  --out_dir outputs/
```

Возвращает:

* `semantic_chunks.json`
* `flat_chunks.tsv`
* отчёт `chunk_report.html`

---

> **См. также:**
> - [docs/implementation_plan.md](implementation_plan.md) — общий план, стандарты интеграции, требования к chunk_metadata_adapter
> - [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md) — спецификация расширения и патча для адаптера

(продолжение: **часть 3 – метрики качества, тест‑корпус, CI‑pipeline**)
