# Smart Chunker Engine: ТЗ (часть 4 из N)

**Официальный репозиторий:** [git@github.com:maverikod/vvz-smart-chunker-engine.git](git@github.com:maverikod/vvz-smart-chunker-engine.git)

> **Внимание!** Все операции с метаданными чанков (создание, хранение, экспорт, сериализация, статусы, метрики) должны выполняться исключительно через API и модели пакета [chunk_metadata_adapter](https://pypi.org/project/chunk-metadata-adapter/) (версии >=1.3.0). Форматы, сериализация, экспорт и валидация должны соответствовать [docs/implementation_plan.md](implementation_plan.md) и [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md).

## 4. Форматы данных и метаданные

### 4.1 Входные артефакты

| Имя файла            | Тип              | Описание                                                |
| -------------------- | ---------------- | ------------------------------------------------------- |
| `raw_text.txt`       | UTF‑8 plain      | Исходный текст, до 150 КБ (один документ)               |
| `config.yaml`        | YAML             | Пороги, включение модулей, пути моделей                 |
| `block_offsets.json` | JSON‑array\[int] | (необяз.) ручная разметка крупных блоков для калибровки |

### 4.2 Промежуточные форматы

| Этап                   | Файл                  | Схема                       |
| ---------------------- | --------------------- | --------------------------- |
| После Pre‑Normalize    | `normalized.txt`      | plain text                  |
| После первичного split | `chunks_raw.json`     | `List[ChunkRaw]` (см. ниже) |
| После iterative refine | `chunks_refined.json` | `List[SemanticChunk]`       |

#### 4.2.1 Schema `ChunkRaw`

```json
{
  "id": "<uuid>",
  "text": "...",
  "start": 1234,              // byte offset in original
  "end": 1734,
  "method": "hybrid|semantic|fixed",
  "cohesion": 0.48,
  "boundary_prev": 0.81,
  "boundary_next": 0.32
}
```

### 4.3 Выходные форматы

| Файл                   | Тип                   | Поле `status`                                 |           |                    |
| ---------------------- | --------------------- | --------------------------------------------- | --------- | ------------------ |
| `semantic_chunks.json` | `List[SemanticChunk]` | \`RELIABLE                                    | VALIDATED | REJECTED\` (noise) |
| `flat_chunks.csv`      | CSV / Parquet         | FlatSemanticChunk (см. models)                |           |                    |
| `reports/…`            | PNG / HTML            | length hist, Score‑per‑iter, coverage‑heatmap |           |                    |

### 4.4 Метаданные (добавки)

| Новый field             | Тип   | Описание                                                    |
| ----------------------- | ----- | ----------------------------------------------------------- |
| `metrics.cohesion`      | float | 0–1, средняя близость троек в чанке                         |
| `metrics.boundary_prev` | float | cos‑sim последней тройки с первой тройкой предыдущего чанка |
| `metrics.boundary_next` | float | аналогично для следующего                                   |
| `metrics.coverage`      | float | 1 – cos(sentence, TopicCore)                                |
| `tags` → `off_topic`    | str   | ставится, если `coverage < cov_min`                         |

### 4.5 JSON‑Schema для `SemanticChunk` (фрагмент diff)

```diff
   "metrics": {
     "type": "object",
     ...
+    "properties": {
+       "cohesion": {"type": "number", "minimum": 0, "maximum": 1},
+       "boundary_prev": {"type": "number", "minimum": 0, "maximum": 1},
+       "boundary_next": {"type": "number", "minimum": 0, "maximum": 1},
+       "coverage": {"type": "number", "minimum": 0, "maximum": 1}
+    }
   }
```

### 4.6 Поток данных

1. `raw_text.txt` → **Pre‑Normalize**
2. → `chunks_raw.json` (стартовый метод)
3. → **iterative\_refine** (Part 3): produces `chunks_refined.json`
4. → **MetadataBuilder** + TopicCore → `semantic_chunks.json`
5. → **Flat convert** → `flat_chunks.csv`
6. → Репорты и векторная БД

---

Дайте знать, если нужны изменения; следующим будет **Part 5: CLI, REST и cron‑pipeline**.

---

> **См. также:**
> - [docs/implementation_plan.md](implementation_plan.md) — общий план, стандарты интеграции, требования к chunk_metadata_adapter
> - [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md) — спецификация расширения и патча для адаптера
