# Smart Chunker Engine: ТЗ (часть 5 из N)

**Официальный репозиторий:** [git@github.com:maverikod/vvz-smart-chunker-engine.git](git@github.com:maverikod/vvz-smart-chunker-engine.git)

> **Внимание!** Все операции с метаданными чанков (создание, хранение, экспорт, сериализация, статусы, метрики) должны выполняться исключительно через API и модели пакета [chunk_metadata_adapter](https://pypi.org/project/chunk-metadata-adapter/) (версии >=1.3.0). Форматы, сериализация, экспорт и валидация должны соответствовать [docs/implementation_plan.md](implementation_plan.md) и [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md).

## 5. Наборы тестов и CI‑pipeline

### 5.1 Контрольный корпус

| Корпус          | Размер | Особенности                                                                   | Файл                    |
| --------------- | -----: | ----------------------------------------------------------------------------- | ----------------------- |
| **ML‑RU‑50k**   |  55 КБ | Текст о математ. статистике + ML, шум: пропущенные точки, рандомные заглавные | `data/raw_text_ml.txt`  |
| **Tech‑EN‑30k** |  32 КБ | Англ. документация + код‑фрагменты                                            | `data/raw_text_en.txt`  |
| **OCR‑RU‑20k**  |  21 КБ | OCR‑шум: `l`↔`1`, случайные переносы                                          | `data/raw_text_ocr.txt` |

##### Формат чек‑листов

```
<corpus_name>/block_offsets.json        # manual large blocks
<corpus_name>/gold_sentences.json       # sentence IDs ground‑truth
```

### 5.2 Авто‑валидация (pytest + GitHub Actions)

```
        name: Chunker CI
        on: [push, pull_request]
        jobs:
          test:
            runs-on: ubuntu-latest
            steps:
              - uses: actions/checkout@v4
              - uses: actions/setup-python@v5
                with:
                  python-version: '3.10'
              - run: pip install -r requirements.txt
              - run: pytest tests/ --junitxml=reports/results.xml
              - name: Upload artifacts
                uses: actions/upload-artifact@v4
                with:
                  path: reports/
```

### 5.3 Метрики качества (evaluate\_boundaries.py)

| Метрика           | Порог OK  | Файл отчёта                        |
| ----------------- | --------- | ---------------------------------- |
| **F1\_boundary**  | ≥ 0.90    | `reports/boundaries_<corpus>.json` |
| **Noise\_rate**   | ≤ 3 %     | + в отчёте                         |
| **Avg\_len ± CV** | CV ≤ 30 % | чек‑лист                           |

### 5.4 Код проверки

```bash
python evaluate_boundaries.py \
  --chunks outputs/<corpus>/chunks.json \
  --gold   data/<corpus>/gold_sentences.json \
  --output reports/boundaries_<corpus>.json
```

Скрипт выводит Precision, Recall, F1, Noise‑rate.

---

### 5.5 Статус‑гейты в CI

* **failure** — любая метрика ниже порога.
* **warning** — F1 0.88‑0.90 или Noise 3‑4 % (pull‑request помечается).
* **success** — все метрики выше целевых.

Следующая часть — **6. API endpoints / CLI**.

---

> **См. также:**
> - [docs/implementation_plan.md](implementation_plan.md) — общий план, стандарты интеграции, требования к chunk_metadata_adapter
> - [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md) — спецификация расширения и патча для адаптера
