# Smart Chunker Engine: ТЗ (часть 6 из N)

**Официальный репозиторий:** [git@github.com:maverikod/vvz-smart-chunker-engine.git](git@github.com:maverikod/vvz-smart-chunker-engine.git)

> **Внимание!** Все операции с метаданными чанков (создание, хранение, экспорт, сериализация, статусы, метрики) должны выполняться исключительно через API и модели пакета [chunk_metadata_adapter](https://pypi.org/project/chunk-metadata-adapter/) (версии >=1.3.0). Форматы, сериализация, экспорт и валидация должны соответствовать [docs/implementation_plan.md](implementation_plan.md) и [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md).

## 6. Наборы тестов и CI‑pipeline

### 6.1 Контрольный корпус

| Корпус           | Размер | Особенности                                                                       | Файл                    |
| ---------------- | -----: | --------------------------------------------------------------------------------- | ----------------------- |
| **ML‑RU‑50k**    |  55 КБ | Статистика + ML, отсутствуют точки, рандомные заглавные, мусорные абзац‑разрывы   | `data/raw_text_ml.txt`  |
| **Tech‑EN‑30k**  |  32 КБ | Английская тех‑дока, вкрапления кода (`python`), неверные точки внутри переменных | `data/raw_text_en.txt`  |
| **OCR‑RU‑20k**   |  21 КБ | OCR‑шум: `l`↔`1`, пропущенные «ё», случайные пробелы в словах                     | `data/raw_text_ocr.txt` |
| **ASR‑RU‑15k**   |  17 КБ | Расшифровка речи: нет пунктуации, повторы слов, «э-э», «ну»‑филллеры              | `data/raw_text_asr.txt` |
| **Code‑Mix‑10k** |  11 КБ | Смешанный русский/английский + JSON/SQL сниппеты                                  | `data/raw_text_mix.txt` |

Каждый файл снабжён `block_offsets.json` — опорная разметка крупных смысловых блоков.

---

### 6.2 Метрики, вычисляемые в CI

| Метрика                | Скрипт                   | Порог «красного» | Порог «жёлтого» | Что делать при провале |
| ---------------------- | ------------------------ | ---------------- | --------------- | ---------------------- |
| **F1\_boundaries**     | `evaluate_boundaries.py` | < 0.88           | 0.88‑0.90       | падение сборки         |
| **Noise %**            | `calc_noise_rate.py`     | > 4 %            | 3‑4 %           | warning в PR           |
| **CV\_length**         | `length_stats.py`        | > 35 %           | 30‑35 %         | рекоменд. MERGE/SPLIT  |
| **Coverage\_min**      | `coverage_check.py`      | < 0.55           | 0.55‑0.60       | пометить NEEDS\_REVIEW |
| **build\_sec** (20 КБ) | `time_benchmark.py`      | > 12 сек         | 8‑12 сек        | оптимизировать модель  |
| **peak_RAM** (20 КБ) | `memory_benchmark.py` | > 1024 MB | 768‑1024 MB | оптимизировать память |

Все скрипты пишут JUnit‑XML ⟶ отчёт GitHub Actions + badge.

---

### 6.3 GitHub Actions workflow

```yaml
name: CI‑Chunker

on: [push, pull_request]

jobs:
  build-test:
    runs-on: ubuntu-latest
    steps:
      - uses: actions/checkout@v4
      - uses: actions/setup-python@v5
        with:
          python-version: '3.11'
      - name: Install deps
        run: |
          pip install -r requirements.txt
          python -m spacy download ru_core_news_md
      - name: Run pipeline on corpora
        run: python pipeline_main.py --batch data/*.txt --config config.yaml
      - name: Run tests
        run: |
          python evaluate_boundaries.py reports/chunks.json data/block_offsets.json --junit xmlout.xml
          python calc_noise_rate.py    reports/chunks.json --junit noise.xml
          python length_stats.py       reports/chunks.json --junit len.xml
      - name: Upload test reports
        uses: actions/upload-artifact@v4
        with:
          name: junit
          path: "*.xml"
      - name: Merge JUnit & annotate PR
        uses: mikepenz/action-junit-report@v4
        with:
          report_paths: "*.xml"
          summary: true
```

### 6.4 Smoke‑тест (pre‑commit)

* запускается на 2‑КБ сэмпле `sample_text.txt`
* проверяет отсутствие исключений, ≤ 3 сек на CPU.

---

> **См. также:**
> - [docs/implementation_plan.md](implementation_plan.md) — общий план, стандарты интеграции, требования к chunk_metadata_adapter
> - [docs/metadata_adapter_patch_spec.md](metadata_adapter_patch_spec.md) — спецификация расширения и патча для адаптера